@@ -3,12 +3,11 @@ import os
 from datetime import datetime, timedelta, date
 from decimal import Decimal
 from os.path import join
-from pprint import pprint
 from urllib.parse import urlparse
 from django.utils import timezone
 from typing import List
-
 from django.utils.timezone import now
+from rest_framework.test import APIClient
 
 from jutil.modelfields import SafeCharField, SafeTextField
 from jutil.middleware import logger as jutil_middleware_logger, ActivateUserProfileTimezoneMiddleware
@@ -27,21 +26,20 @@ from rest_framework.exceptions import NotAuthenticated
 from jutil.admin import admin_log, admin_obj_url, admin_obj_link, ModelAdminBase, AdminLogEntryMixin
 from jutil.auth import AuthUserMixin, get_auth_user, get_auth_user_or_none
 from jutil.command import get_date_range_by_name, add_date_range_arguments, parse_date_range_arguments
-from jutil.dict import dict_to_html, choices_label
 from jutil.email import make_email_recipient_list
 from jutil.middleware import EnsureOriginMiddleware, LogExceptionMiddleware, EnsureLanguageCookieMiddleware
 from jutil.model import is_model_field_changed, clone_model, get_model_field_label_and_value, get_object_or_none, \
     wait_object_or_none
 from jutil.request import get_ip_info
-from jutil.responses import FileSystemFileResponse, CsvResponse
-from jutil.testing import DefaultTestSetupMixin
-from jutil.urls import url_equals, url_mod, url_host
+from jutil.responses import CsvResponse
+from jutil.testing import TestSetupMixin
+from jutil.urls import modify_url
 from jutil.xml import xml_to_dict, dict_to_element, _xml_filter_tag_name
 from jutil.dates import add_month, per_delta, per_month, this_week, next_month, next_week, this_month, last_month, \
     last_year, last_week, yesterday, end_of_month, this_year, get_time_steps, TIME_STEP_DAILY
 from jutil.format import format_full_name, format_xml, format_xml_bytes, format_timedelta, dec1, dec2, dec3, dec4, dec5, \
     dec6, format_table, ucfirst_lazy, strip_media_root, get_media_full_path, camel_case_to_underscore, \
-    underscore_to_camel_case, format_as_html_json
+    underscore_to_camel_case, format_as_html_json, format_dict_as_html, choices_label
 from jutil.parse import parse_datetime, parse_bool, parse_datetime_or_none
 from jutil.validators import fi_payment_reference_number, se_ssn_validator, se_ssn_filter, fi_iban_validator, \
     se_iban_validator, iban_filter_readable, email_filter, iban_validator, iban_bank_info, fi_company_org_id_validator, \
@@ -110,18 +108,18 @@ class MyCustomAdmin(ModelAdminBase):
         return self.model.objects.get(id=obj_id)
 
 
-class Tests(TestCase, DefaultTestSetupMixin):
+class Tests(TestCase, TestSetupMixin):
     def setUp(self):
-        super().setUp()
-        user = self.add_test_user('test@example.com', 'test1234')
+        self.user = user = self.add_test_user('test@example.com', 'test1234')
         assert isinstance(user, User)
         user.is_superuser = True
         user.is_staff = True
         user.save()
         self.client = Client()
 
-    def tearDown(self):
-        super().setUp()
+    def test_api_client(self):
+        api_client = self.create_api_client()
+        self.assertTrue(isinstance(api_client, APIClient))
 
     def test_payment_reference(self):
         self.assertEqual(fi_payment_reference_number('100'), '1009')
@@ -293,11 +291,8 @@ class Tests(TestCase, DefaultTestSetupMixin):
 
     def test_urls(self):
         url = 'http://yle.fi/uutiset/3-8045550?a=123&b=456'
-        self.assertEqual(url_host(url), 'yle.fi')
-        self.assertTrue(
-            url_equals('http://yle.fi/uutiset/3-8045550?a=123&b=456', 'http://yle.fi/uutiset/3-8045550?b=456&a=123'))
-        self.assertTrue(url_equals(url_mod('http://yle.fi/uutiset/3-8045550?a=123&b=456', {'b': '123', 'a': '456'}),
-                                   'http://yle.fi/uutiset/3-8045550?b=123&a=456'))
+        self.assertEqual(modify_url('http://yle.fi/uutiset/3-8045550?a=123&b=456', {'a': '123', 'b': '456'}),
+                         'http://yle.fi/uutiset/3-8045550?a=123&b=456')
 
     def test_email_filter_and_validation(self):
         emails = [
@@ -668,10 +663,10 @@ class Tests(TestCase, DefaultTestSetupMixin):
         self.assertEqual(email_sanitizer('test@example.com'), 'test@example.com')
         self.assertEqual(email_sanitizer('testexample.com'), '')
 
-    def test_dict_to_html(self):
+    def test_format_dict_as_html(self):
         a = {'b': 1, 'c': {'@testVariable': '123'}}
         res = '<pre>B: 1\nC:\n    Test variable: 123\n\n</pre>'
-        self.assertEqual(dict_to_html(a), res)
+        self.assertEqual(format_dict_as_html(a), res)
 
     def test_format_xml(self):
         assert settings.XMLLINT_PATH, 'add e.g. XMLLINT_PATH = "/usr/bin/xmllint" to settings.py'
